# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalIndications(BaseModel):
    delete_medical_indications: Optional[
        List[Optional["DeleteMedicalIndicationsDeleteMedicalIndications"]]
    ] = Field(alias="deleteMedicalIndications")


class DeleteMedicalIndicationsDeleteMedicalIndications(BaseModel):
    id: str
    state: EntityState


DeleteMedicalIndications.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class GetCollection(BaseModel):
    collection: Optional["GetCollectionCollection"]


class GetCollectionCollection(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "GetCollectionCollectionOwner"
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[List[Optional["GetCollectionCollectionContents"]]]


class GetCollectionCollectionOwner(BaseModel):
    id: str


class GetCollectionCollectionContents(BaseModel):
    id: str
    name: str


GetCollection.model_rebuild()
GetCollectionCollection.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalDevices(BaseModel):
    delete_medical_devices: Optional[
        List[Optional["DeleteMedicalDevicesDeleteMedicalDevices"]]
    ] = Field(alias="deleteMedicalDevices")


class DeleteMedicalDevicesDeleteMedicalDevices(BaseModel):
    id: str
    state: EntityState


DeleteMedicalDevices.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    EntityState,
    FileTypes,
    ImageProjectionTypes,
    LinkTypes,
    MailImportance,
    MailPriority,
    MailSensitivity,
    ObservableTypes,
    OccurrenceTypes,
    OrientationTypes,
    TextRoles,
)


class GetContent(BaseModel):
    content: Optional["GetContentContent"]


class GetContentContent(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "GetContentContentOwner"
    state: EntityState
    original_date: Optional[Any] = Field(alias="originalDate")
    finished_date: Optional[Any] = Field(alias="finishedDate")
    workflow_duration: Optional[Any] = Field(alias="workflowDuration")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    markdown: Optional[str]
    address: Optional["GetContentContentAddress"]
    location: Optional["GetContentContentLocation"]
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    file_name: Optional[str] = Field(alias="fileName")
    file_size: Optional[Any] = Field(alias="fileSize")
    master_uri: Optional[Any] = Field(alias="masterUri")
    image_uri: Optional[Any] = Field(alias="imageUri")
    text_uri: Optional[Any] = Field(alias="textUri")
    audio_uri: Optional[Any] = Field(alias="audioUri")
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    summary: Optional[str]
    custom_summary: Optional[str] = Field(alias="customSummary")
    keywords: Optional[List[str]]
    bullets: Optional[List[str]]
    headlines: Optional[List[str]]
    posts: Optional[List[str]]
    chapters: Optional[List[str]]
    questions: Optional[List[str]]
    video: Optional["GetContentContentVideo"]
    audio: Optional["GetContentContentAudio"]
    image: Optional["GetContentContentImage"]
    document: Optional["GetContentContentDocument"]
    email: Optional["GetContentContentEmail"]
    issue: Optional["GetContentContentIssue"]
    package: Optional["GetContentContentPackage"]
    language: Optional["GetContentContentLanguage"]
    parent: Optional["GetContentContentParent"]
    children: Optional[List[Optional["GetContentContentChildren"]]]
    feed: Optional["GetContentContentFeed"]
    collections: Optional[List[Optional["GetContentContentCollections"]]]
    links: Optional[List["GetContentContentLinks"]]
    observations: Optional[List[Optional["GetContentContentObservations"]]]
    workflow: Optional["GetContentContentWorkflow"]
    pages: Optional[List["GetContentContentPages"]]
    segments: Optional[List["GetContentContentSegments"]]
    frames: Optional[List["GetContentContentFrames"]]
    error: Optional[str]


class GetContentContentOwner(BaseModel):
    id: str


class GetContentContentAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class GetContentContentLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class GetContentContentVideo(BaseModel):
    width: Optional[int]
    height: Optional[int]
    duration: Optional[Any]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    title: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]


class GetContentContentAudio(BaseModel):
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]
    series: Optional[str]
    episode: Optional[str]
    episode_type: Optional[str] = Field(alias="episodeType")
    season: Optional[str]
    publisher: Optional[str]
    copyright: Optional[str]
    genre: Optional[str]
    title: Optional[str]
    description: Optional[str]
    bitrate: Optional[int]
    channels: Optional[int]
    sample_rate: Optional[int] = Field(alias="sampleRate")
    bits_per_sample: Optional[int] = Field(alias="bitsPerSample")
    duration: Optional[Any]


class GetContentContentImage(BaseModel):
    width: Optional[int]
    height: Optional[int]
    resolution_x: Optional[int] = Field(alias="resolutionX")
    resolution_y: Optional[int] = Field(alias="resolutionY")
    bits_per_component: Optional[int] = Field(alias="bitsPerComponent")
    components: Optional[int]
    projection_type: Optional[ImageProjectionTypes] = Field(alias="projectionType")
    orientation: Optional[OrientationTypes]
    description: Optional[str]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    lens: Optional[str]
    focal_length: Optional[float] = Field(alias="focalLength")
    exposure_time: Optional[str] = Field(alias="exposureTime")
    f_number: Optional[str] = Field(alias="fNumber")
    iso: Optional[str]
    heading: Optional[float]
    pitch: Optional[float]


class GetContentContentDocument(BaseModel):
    title: Optional[str]
    subject: Optional[str]
    summary: Optional[str]
    author: Optional[str]
    publisher: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    page_count: Optional[int] = Field(alias="pageCount")
    worksheet_count: Optional[int] = Field(alias="worksheetCount")
    slide_count: Optional[int] = Field(alias="slideCount")
    word_count: Optional[int] = Field(alias="wordCount")
    line_count: Optional[int] = Field(alias="lineCount")
    paragraph_count: Optional[int] = Field(alias="paragraphCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")
    has_digital_signature: Optional[bool] = Field(alias="hasDigitalSignature")


class GetContentContentEmail(BaseModel):
    identifier: Optional[str]
    subject: Optional[str]
    labels: Optional[List[Optional[str]]]
    sensitivity: Optional[MailSensitivity]
    priority: Optional[MailPriority]
    importance: Optional[MailImportance]
    from_: Optional[List[Optional["GetContentContentEmailFrom"]]] = Field(alias="from")
    to: Optional[List[Optional["GetContentContentEmailTo"]]]
    cc: Optional[List[Optional["GetContentContentEmailCc"]]]
    bcc: Optional[List[Optional["GetContentContentEmailBcc"]]]


class GetContentContentEmailFrom(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class GetContentContentEmailTo(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class GetContentContentEmailCc(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class GetContentContentEmailBcc(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class GetContentContentIssue(BaseModel):
    identifier: Optional[str]
    title: Optional[str]
    project: Optional[str]
    team: Optional[str]
    status: Optional[str]
    priority: Optional[str]
    type: Optional[str]
    labels: Optional[List[Optional[str]]]


class GetContentContentPackage(BaseModel):
    file_count: Optional[int] = Field(alias="fileCount")
    folder_count: Optional[int] = Field(alias="folderCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")


class GetContentContentLanguage(BaseModel):
    languages: Optional[List[Optional[str]]]


class GetContentContentParent(BaseModel):
    id: str
    name: str


class GetContentContentChildren(BaseModel):
    id: str
    name: str


class GetContentContentFeed(BaseModel):
    id: str
    name: str


class GetContentContentCollections(BaseModel):
    id: str
    name: str


class GetContentContentLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")


class GetContentContentObservations(BaseModel):
    id: str
    type: ObservableTypes
    observable: "GetContentContentObservationsObservable"
    related: Optional["GetContentContentObservationsRelated"]
    related_type: Optional[ObservableTypes] = Field(alias="relatedType")
    relation: Optional[str]
    occurrences: Optional[List[Optional["GetContentContentObservationsOccurrences"]]]
    state: EntityState


class GetContentContentObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class GetContentContentObservationsRelated(BaseModel):
    id: str
    name: Optional[str]


class GetContentContentObservationsOccurrences(BaseModel):
    type: Optional[OccurrenceTypes]
    confidence: Optional[float]
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_index: Optional[int] = Field(alias="pageIndex")
    bounding_box: Optional["GetContentContentObservationsOccurrencesBoundingBox"] = (
        Field(alias="boundingBox")
    )


class GetContentContentObservationsOccurrencesBoundingBox(BaseModel):
    left: Optional[float]
    top: Optional[float]
    width: Optional[float]
    height: Optional[float]


class GetContentContentWorkflow(BaseModel):
    id: str
    name: str


class GetContentContentPages(BaseModel):
    index: Optional[int]
    relevance: Optional[float]
    chunks: Optional[List[Optional["GetContentContentPagesChunks"]]]


class GetContentContentPagesChunks(BaseModel):
    index: Optional[int]
    page_index: Optional[int] = Field(alias="pageIndex")
    row_index: Optional[int] = Field(alias="rowIndex")
    column_index: Optional[int] = Field(alias="columnIndex")
    confidence: Optional[float]
    text: Optional[str]
    role: Optional[TextRoles]
    relevance: Optional[float]


class GetContentContentSegments(BaseModel):
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    text: Optional[str]
    relevance: Optional[float]


class GetContentContentFrames(BaseModel):
    index: Optional[int]
    description: Optional[str]
    text: Optional[str]
    relevance: Optional[float]


GetContent.model_rebuild()
GetContentContent.model_rebuild()
GetContentContentEmail.model_rebuild()
GetContentContentObservations.model_rebuild()
GetContentContentObservationsOccurrences.model_rebuild()
GetContentContentPages.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeletePersons(BaseModel):
    delete_persons: Optional[List[Optional["DeletePersonsDeletePersons"]]] = Field(
        alias="deletePersons"
    )


class DeletePersonsDeletePersons(BaseModel):
    id: str
    state: EntityState


DeletePersons.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateRepo(BaseModel):
    update_repo: Optional["UpdateRepoUpdateRepo"] = Field(alias="updateRepo")


class UpdateRepoUpdateRepo(BaseModel):
    id: str
    name: str


UpdateRepo.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AlertTypes,
    ContentPublishingServiceTypes,
    ContentTypes,
    ElevenLabsModels,
    EntityState,
    FileTypes,
    IntegrationServiceTypes,
    ObservableTypes,
)


class QueryAlerts(BaseModel):
    alerts: Optional["QueryAlertsAlerts"]


class QueryAlertsAlerts(BaseModel):
    results: Optional[List[Optional["QueryAlertsAlertsResults"]]]


class QueryAlertsAlertsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "QueryAlertsAlertsResultsOwner"
    state: EntityState
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: AlertTypes
    summary_prompt: Optional[str] = Field(alias="summaryPrompt")
    publish_prompt: str = Field(alias="publishPrompt")
    filter: Optional["QueryAlertsAlertsResultsFilter"]
    integration: "QueryAlertsAlertsResultsIntegration"
    publishing: "QueryAlertsAlertsResultsPublishing"
    summary_specification: Optional["QueryAlertsAlertsResultsSummarySpecification"] = (
        Field(alias="summarySpecification")
    )
    publish_specification: Optional["QueryAlertsAlertsResultsPublishSpecification"] = (
        Field(alias="publishSpecification")
    )
    last_alert_date: Optional[Any] = Field(alias="lastAlertDate")


class QueryAlertsAlertsResultsOwner(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilter(BaseModel):
    date_range: Optional["QueryAlertsAlertsResultsFilterDateRange"] = Field(
        alias="dateRange"
    )
    creation_date_range: Optional["QueryAlertsAlertsResultsFilterCreationDateRange"] = (
        Field(alias="creationDateRange")
    )
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    contents: Optional[List["QueryAlertsAlertsResultsFilterContents"]]
    feeds: Optional[List["QueryAlertsAlertsResultsFilterFeeds"]]
    workflows: Optional[List["QueryAlertsAlertsResultsFilterWorkflows"]]
    collections: Optional[List["QueryAlertsAlertsResultsFilterCollections"]]
    observations: Optional[List["QueryAlertsAlertsResultsFilterObservations"]]
    or_: Optional[List["QueryAlertsAlertsResultsFilterOr"]] = Field(alias="or")
    and_: Optional[List["QueryAlertsAlertsResultsFilterAnd"]] = Field(alias="and")


class QueryAlertsAlertsResultsFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryAlertsAlertsResultsFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryAlertsAlertsResultsFilterContents(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterFeeds(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterWorkflows(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterCollections(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryAlertsAlertsResultsFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryAlertsAlertsResultsFilterObservationsObservable(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterOr(BaseModel):
    feeds: Optional[List["QueryAlertsAlertsResultsFilterOrFeeds"]]
    workflows: Optional[List["QueryAlertsAlertsResultsFilterOrWorkflows"]]
    collections: Optional[List["QueryAlertsAlertsResultsFilterOrCollections"]]
    observations: Optional[List["QueryAlertsAlertsResultsFilterOrObservations"]]


class QueryAlertsAlertsResultsFilterOrFeeds(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterOrWorkflows(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterOrCollections(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryAlertsAlertsResultsFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryAlertsAlertsResultsFilterOrObservationsObservable(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterAnd(BaseModel):
    feeds: Optional[List["QueryAlertsAlertsResultsFilterAndFeeds"]]
    workflows: Optional[List["QueryAlertsAlertsResultsFilterAndWorkflows"]]
    collections: Optional[List["QueryAlertsAlertsResultsFilterAndCollections"]]
    observations: Optional[List["QueryAlertsAlertsResultsFilterAndObservations"]]


class QueryAlertsAlertsResultsFilterAndFeeds(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterAndWorkflows(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterAndCollections(BaseModel):
    id: str


class QueryAlertsAlertsResultsFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryAlertsAlertsResultsFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryAlertsAlertsResultsFilterAndObservationsObservable(BaseModel):
    id: str


class QueryAlertsAlertsResultsIntegration(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["QueryAlertsAlertsResultsIntegrationSlack"]


class QueryAlertsAlertsResultsIntegrationSlack(BaseModel):
    token: str
    channel: str


class QueryAlertsAlertsResultsPublishing(BaseModel):
    type: ContentPublishingServiceTypes
    eleven_labs: Optional["QueryAlertsAlertsResultsPublishingElevenLabs"] = Field(
        alias="elevenLabs"
    )


class QueryAlertsAlertsResultsPublishingElevenLabs(BaseModel):
    model: Optional[ElevenLabsModels]
    voice: Optional[str]


class QueryAlertsAlertsResultsSummarySpecification(BaseModel):
    id: str


class QueryAlertsAlertsResultsPublishSpecification(BaseModel):
    id: str


QueryAlerts.model_rebuild()
QueryAlertsAlerts.model_rebuild()
QueryAlertsAlertsResults.model_rebuild()
QueryAlertsAlertsResultsFilter.model_rebuild()
QueryAlertsAlertsResultsFilterObservations.model_rebuild()
QueryAlertsAlertsResultsFilterOr.model_rebuild()
QueryAlertsAlertsResultsFilterOrObservations.model_rebuild()
QueryAlertsAlertsResultsFilterAnd.model_rebuild()
QueryAlertsAlertsResultsFilterAndObservations.model_rebuild()
QueryAlertsAlertsResultsIntegration.model_rebuild()
QueryAlertsAlertsResultsPublishing.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountPlaces(BaseModel):
    count_places: Optional["CountPlacesCountPlaces"] = Field(alias="countPlaces")


class CountPlacesCountPlaces(BaseModel):
    count: Optional[Any]


CountPlaces.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalTherapy(BaseModel):
    update_medical_therapy: Optional["UpdateMedicalTherapyUpdateMedicalTherapy"] = (
        Field(alias="updateMedicalTherapy")
    )


class UpdateMedicalTherapyUpdateMedicalTherapy(BaseModel):
    id: str
    name: str


UpdateMedicalTherapy.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalIndications(BaseModel):
    count_medical_indications: Optional[
        "CountMedicalIndicationsCountMedicalIndications"
    ] = Field(alias="countMedicalIndications")


class CountMedicalIndicationsCountMedicalIndications(BaseModel):
    count: Optional[Any]


CountMedicalIndications.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalTests(BaseModel):
    count_medical_tests: Optional["CountMedicalTestsCountMedicalTests"] = Field(
        alias="countMedicalTests"
    )


class CountMedicalTestsCountMedicalTests(BaseModel):
    count: Optional[Any]


CountMedicalTests.model_rebuild()
